// import 'package:fastor_app_ui_widget/firebase_options.dart';
import 'package:fastor_app_ui_widget/resource/uiFastor/language/LanguageTools.dart';
import 'package:fastor_app_ui_widget/resource/uiFastor/statusBar/StatusBarConstant.dart';
import 'package:flutter/material.dart';

//third libaray
import 'package:flutter/material.dart'  if (dart.library.html)   'dart:html';
import 'package:easy_localization/easy_localization.dart' hide TextDirection;
import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:universal_io/io.dart';

//firebase import
import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_core/firebase_core.dart';

class runAppFastor {

  Widget launcher;
  FirebaseOptions? firebaseOptionsCurrentPlatform;

  runAppFastor({
    required this.launcher,
    FirebaseOptions?  firebaseOptionsCurrentPlatform
  }){
    this.launcher = launcher;
    this.firebaseOptionsCurrentPlatform = firebaseOptionsCurrentPlatform;

    //main
    new MainTemplate().main(launcher:  launcher,
    firebaseOptionsCurrentPlatform: firebaseOptionsCurrentPlatform );
  }

}


class MainTemplate {



  Future<void> main( {
  required Widget launcher,
    FirebaseOptions? firebaseOptionsCurrentPlatform
} ) async {

    //webview
    await WidgetsFlutterBinding.ensureInitialized();

    //webview
    if (Platform.isAndroid) {
      await AndroidInAppWebViewController.setWebContentsDebuggingEnabled(true);

      var swAvailable = await AndroidWebViewFeature.isFeatureSupported(
          AndroidWebViewFeature.SERVICE_WORKER_BASIC_USAGE);
      var swInterceptAvailable = await AndroidWebViewFeature.isFeatureSupported(
          AndroidWebViewFeature.SERVICE_WORKER_SHOULD_INTERCEPT_REQUEST);

      if (swAvailable && swInterceptAvailable) {
        AndroidServiceWorkerController serviceWorkerController =
        AndroidServiceWorkerController.instance();

        serviceWorkerController.serviceWorkerClient = AndroidServiceWorkerClient(
          shouldInterceptRequest: (request) async {
            print(request);
            return null;
          },
        );
      }
    }

    //translation
    await EasyLocalization.ensureInitialized();

    //firebase
    await Firebase.initializeApp(
      options: firebaseOptionsCurrentPlatform,// DefaultFirebaseOptions.currentPlatform,
    );

    //run
    runApp(

      EasyLocalization(
          supportedLocales:  LanguageTools.listLocal,
          path:  'assets/translations',// 'assets/translations',
          fallbackLocale: LanguageTools.defaultLocal,
          child: _AppTheme( launcher )
      ),
    );
  }

}


//--------------------------------------------------------------------- app theme

class _AppTheme extends StatelessWidget {

  late BuildContext context;

  Widget launcher;

  _AppTheme(this.launcher);


  @override
  Widget build(BuildContext context) {
    this.context = context;

    //theme
    return getMaterialApp();
  }

  /**
   * import 'package:firebase_analytics/firebase_analytics.dart';
   */
  static FirebaseAnalytics analytics = FirebaseAnalytics.instance;
  static FirebaseAnalyticsObserver observer = new FirebaseAnalyticsObserver(
      analytics: analytics);


  MaterialApp getMaterialApp() {
    return MaterialApp(

      //language translation
        locale: context.locale,
        supportedLocales: context.supportedLocales,
        localizationsDelegates: context.localizationDelegates,

        //SEO
        /**
         * - must to import
         * import 'package:seo_renderer/seo_renderer.dart';
         */
        title: 'Fastor',

        navigatorObservers: <NavigatorObserver>[observer],
        // navigatorObservers: <RouteObserver<ModalRoute<void>>>[ routeObserver ],

        //
        color: StatusBarConstant.colorBackground,
        debugShowCheckedModeBanner: false,


        //language direction RTL or LTR
        home: Directionality( // add this
          textDirection: LanguageTools.getTextDirection(context),
          // set this property
          child: launcher,
        )

    );
  }

}